@@ -22,21 +22,27 @@
 #
 # put a raw copy of FlexLexer.h instead of a #include <FlexLexer.h>
 # for portability purpose
-#
+# 
 # flexfix.sh usage:
 #   flex -+ -i $< -t -o file.c | flexfix.sh /usr/local/include/FlexLexer.h > file.c"; \
-# 
+#
+# note: with recent flex version >= 2.6.4 there is no more FlexLexer.h
+# and this fix is no more need : in that case, $1="" i.e. $#=0
+# and we skip the fix.
+#
 TMPDIR=${TMPDIR-"/tmp"}
 sedfile=${TMPDIR}/flexfix-$$.sed
 
-cat > $sedfile << EOF
+if test $# -gt 0 && test -f $1; then
+  cat > $sedfile << EOF
 s/class istream;/#include <iostream.h>/
 /^#include <FlexLexer.h>/ {
 r $1
 d
 }
 EOF
-
-sed -f $sedfile
-/bin/rm -f $sedfile
-
+  sed -f $sedfile
+  /bin/rm -f $sedfile
+else 
+  cat
+fi
