@@ -534,22 +534,6 @@ bigfloat_comparator(>=)
 
 // math functions
 
-#ifdef TODO
-doubledouble hypot(const doubledouble, const doubledouble);
-doubledouble cub(const doubledouble&);
-doubledouble rint(const doubledouble&);
-doubledouble fmod(const doubledouble&, const int);
-doubledouble modf(const doubledouble&, doubledouble *ip);
-void sincos(const doubledouble x, doubledouble& sinx, doubledouble& cosx);
-doubledouble atan2(const doubledouble&, const doubledouble&);
-doubledouble asin(const doubledouble&);
-doubledouble erf(const doubledouble);
-doubledouble erfc(const doubledouble);
-doubledouble gamma(const doubledouble);
-int  digits(const doubledouble&,const doubledouble&);
-doubledouble modr(const doubledouble a, const doubledouble b, int& n, doubledouble& rem);
-#endif // TODO
-
 #define bigfloat_math_function(fct, cln_fct)		\
 template <int N>					\
 inline							\
