@@ -111,7 +111,7 @@ BOOLEAN MANIPULATORS:
     @itemx cut
     @itemx iso
     @itemx split
-       when using the @code{vtk} or @code{mayavi} manipulators
+       when using the @code{vtk} or @code{paraview} manipulators
        for a mesh or a field.
     
     @item volume
@@ -132,6 +132,15 @@ BOOLEAN MANIPULATORS:
 	a tridimensionnal surface elevation.
        	For @code{vtk} or @code{plotmtv} rendering.
 
+@fiindex @file{.vtk} visualization toolkit
+@toindex @code{paraview}
+@clindex branch
+
+    @item skipvtk
+	For the @code{branch} class.
+	Combined with @code{paraview}, only create the main python @file{.py} file,
+        do not regenerate all the @file{.vtk} data files.
+
     @end table
 
 @findex fastfieldload
@@ -249,14 +258,14 @@ FILE FORMAT MANIPULATORS:
 	@file{.tcl} command script file
 	and run the @code{vtk} command
 	on the @file{.tcl}. 
-@fiindex @file{.py} python script file (for mayavi visualization tool)
-@toindex @code{mayavi}
-    @item mayavi
+@fiindex @file{.py} python script file (for paraview visualization tool)
+@toindex @code{paraview}
+    @item paraview
 	for field outputs.
 	Generate @file{.vtk} data file and the
 	@file{.py} command script file
 	and run the @code{python} command on the @file{.py}
-	associated to the @code{mayavi}/@code{vtk} library.
+	associated to the @code{paraview}/@code{vtk} library.
     @item geomview
 	for boundary cad outputs.
 	Generate @file{.off} data file
@@ -298,7 +307,7 @@ COLOR MANIPULATORS:
     	cout << black_and_white  << c;
     @end example
     The default is to generate a color postcript file.
-    Conversely, its act for field rendering, via @code{mayavi}.
+    Conversely, its act for field rendering, via @code{paraview}.
 
 VALUATED MANIPULATORS:
 @pindex mfield
@@ -311,12 +320,20 @@ VALUATED MANIPULATORS:
 @clindex catchmark
     See also @ref{catchmark algorithm} for input-output of vector-valued fields.
     @table @code
-    @item isovalue @var{float}
+    @item  isovalue @var{float}
     @itemx n_isovalue @var{int}
     @itemx n_isovalue_negative @var{int}
-    @itemx vectorscale @var{float}
-    @itemx subdivide @var{float}
-    @itemx rounding_precision @var{float}
+	Used by 2D and 3D graphic renders.
+    @item  vectorscale @var{float}
+	Used for vector field visualizattion.
+@toindex @code{paraview}
+    @item  subdivide @var{float}
+	Used for high-order curved mesh visualizatiion
+        and also for high-order picewise polynomial fields.
+        From paraview-5.5, this features is obsolete.
+    @item label @var{string}
+        For colorbar anotation.
+    @item  rounding_precision @var{float}
 	This manipulator set a rounding precision that could be used
 	by some output functions, e.g. by the @code{geo} class.
 	By default, the rounding value is zero and there is no rounding.
@@ -328,6 +345,9 @@ VALUATED MANIPULATORS:
     @item image_format @var{string}
 	The argument is any valid image format, such as @code{png}, @code{jpg} or @code{pdf},
 	that could be handled by the corresponding graphic render.
+    @item branch_counter @var{int}
+	Counter for even outputed to a stream.
+	Used internally by the branch class during i/o.
     @end table
 End:*/
 
@@ -386,7 +406,6 @@ public:
 		plotmtv,
 		x3d,
 		vtk,				// Visualization ToolKit
-		mayavi,				// mayavi based on vtk
 		paraview,			// paraview based on vtk
 		geomview,			// geomview
 		atom,				// PlotM, from Cornell
@@ -407,12 +426,13 @@ public:
 		velocity,			// vectors rendered as arrows
 		deformation,			// vectors rendered as deformed meshes
                 elevation,              	// 2d scalar field as 3d surface elevation
-                volume,   	           	// 3d scalar field visualization by using ray cast functions (mayavi)
+                volume,   	           	// 3d scalar field visualization by using ray cast functions (paraview)
                 fastfieldload,          	// try to reuse supplied mesh space when loading field
                 bezieradapt, 	  	       	// subdivide each Bezier subpatch instead of global patch, for cad/geomview format
                 lattice, 	  	       	// subdivide each element by two, as in P2-iso-P1, for geo/vtkdata format
-                label, 	  	 	      	// write labels on plotmtv contour lines
+                showlabel, 	 	      	// write labels on plotmtv contour lines
 		autovscale,			// adapt vscale to actual length of vectors and meshsize
+		skipvtk,			// with paraview, only create the .py file, do not regenerate all .vtk
 		reader_on_stdin,		// when read on stdin, add -persist to gnuplot
 
 		last
