@@ -23,12 +23,7 @@
 
 #include "scatch.icc" // compile this code here, but is reused in field2bb
 
-#ifdef _RHEOLEF_HAVE_CLIMITS
 #include <climits>   // PATH_MAX ?
-#else
-#include <limits.h>
-#endif
-
 #include <boost/iostreams/filter/gzip.hpp>
 #include <boost/iostreams/device/file.hpp>
 
@@ -127,7 +122,7 @@ orheostream::_close_internal ()
 #endif //  _RHEOLEF_HAVE_BOOST_IOSTREAMS_GZIP_EMPTY_FILE_BUG
 #ifdef  _RHEOLEF_HAVE_BOOST_IOSTREAMS_GZIP_EMPTY_FILE_BUG_OLD
     if (! (_mode & io::nogz)) {
-      // bug with empty gziped boost::io: workarround by writting an empty thing !
+      // bug with empty gziped boost::io: workaround by writting an empty thing !
       // https://svn.boost.org/trac/boost/ticket/5237
       // the previous fix is buggy: requires a non-empty thing: a newline that does not change rheolef semantic
       trace_macro ("_close_internal: _full_name="<<_full_name<<": gziped => add a carriage return before closing...");
@@ -199,7 +194,7 @@ irheostream::close ()
     _ifs.close();
 }
 irheostream::irheostream (const string& name, const string& suffix)
- : ios::filtering_stream<ios::input>()
+ : ios::filtering_stream<ios::input>(), _ifs()
 {
     open (name, suffix);
 }
@@ -463,7 +458,7 @@ get_full_name_from_rheo_path (const string& rootname, const string& suffix)
 	return string();
     }
     //
-    // rootname has no explicit reference: use seach path
+    // rootname has no explicit reference: use search path
     //
     init_rheo_path();
     unsigned int i_dir = 0;
@@ -495,9 +490,13 @@ is_float (const string& s)
     }
     return true;
 }
-Float
-to_float (const string& s)
-{
-    return Float(atof(s.c_str()));
+Float 
+to_float (const string& s) {
+  // more robust than atof when Float=float128
+  stringstream ss(s);
+  Float x;
+  ss >> x;
+  return x;
 }
+
 }// namespace rheolef
