@@ -1,121 +1,126 @@
 #ifndef _RHEO_SMART_POINTER_H
 #define _RHEO_SMART_POINTER_H
-///
-/// This file is part of Rheolef.
-///
-/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
-///
-/// Rheolef is free software; you can redistribute it and/or modify
-/// it under the terms of the GNU General Public License as published by
-/// the Free Software Foundation; either version 2 of the License, or
-/// (at your option) any later version.
-///
-/// Rheolef is distributed in the hope that it will be useful,
-/// but WITHOUT ANY WARRANTY; without even the implied warranty of
-/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-/// GNU General Public License for more details.
-///
-/// You should have received a copy of the GNU General Public License
-/// along with Rheolef; if not, write to the Free Software
-/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-/// 
-/// =========================================================================
 //
-// smart pointers
+// This file is part of Rheolef.
 //
+// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
+//
+// Rheolef is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// Rheolef is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Rheolef; if not, write to the Free Software
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// 
+// =========================================================================
 // author: Pierre.Saramito@imag.fr
-//
-// date: 27 january 2000, updated 11 may 2012.
-//
-/*Class:smart_pointer
-NAME:  @code{smart_pointer}, @code{smart_pointer_clone} - reference counted safe pointer with true copy semantic 
-@clindex smart_pointer
-@clindex smart_pointer_clone
-@cindex reference counting
-@cindex shallow copy
-@cindex smart pointer
-DESCRIPTION:       
-  @noindent
-  Here is a convenient way to implement a true copy semantic,
-  by using shallow copies and reference counting, in order to 
-  minimise memory copies.
-  This concept is generally related to the @dfn{smart pointer}
-  method for managing memory.
+// date:   27 january 2000, updated 11 may 2012.
 
-  @noindent
-  The true semantic copy is defined as follows: if an object 
-  @code{A} is assigned to
-  @code{B}, such as @code{A = B}, every further modification on @code{A} or @code{B}
-  does not modify the other.
+namespace rheolef {
+/**
+@utilclassfile smart_pointer with true copy semantic 
+@addindex reference counting
+@addindex memory management
+@addindex shallow copy
+@addindex smart pointer
 
-  @noindent
-  Notice that this class differs from the @code{boost::shared\_ptr} class
-  that implements safe pointers without the true copy semantic.
+Description
+===========
+Here is a convenient way to implement a true copy semantic,
+by using shallow copies and reference counting, in order to 
+minimise memory copies.
+This concept is generally related to the *smart pointer*
+method for managing memory.
 
-CLONE VARIANT:       
-  @noindent
-  The @code{smart_pointer_clone} variant uses a @code{T* T::clone() const} member
-  function instead of the usual @code{T::T()} copy constructor for obtaining 
-  a true copy of the data.
-  This variant is motivated as follows:
-  when using hierarchies of derived classes (also known as polymorphic classes),
-  the usual copy is not possible because c++ copy constructors cannot be virtual,
-  so you cannot make a copy this way. 
-  This is a well-known problem with C++'s implementation of polymorphism.
+The true semantic copy is defined as follows:
+if an object `A` is assigned to `B`,
+such as `A = B`,
+every further modification on `A` or `B`
+does not modify the other.
+
+Notice that this class differs from the `std::shared_ptr`
+class that implements safe pointers without the true copy semantic.
+
+Clone variant
+=============
+The smart_pointer_clone variant uses a `T* T::clone() const` member
+function instead of the usual `T::T()` copy constructor for obtaining 
+a true copy of the data.
+This variant is motivated as follows:
+when using hierarchies of derived classes (also known as polymorphic classes),
+the usual copy is not possible because c++ copy constructors cannot be virtual,
+so you cannot make a copy this way. 
+This is a well-known problem with C++'s implementation of polymorphism.
  
-  @noindent
-  We uses a solution to the non-virtual copy constructor problem which is
-  suggested by Ellis and Stroustrup in "The Annotated LRM". 
-  The solution is to require the @code{T} class to provide a virtual clone method for every
-  class which makes a copy using new and the correct copy constructor,
-  returning the result as a pointer to the superclass @code{T}.
-  Each subclass of @code{T} overloads this function with its own variant
-  which copies its own type. Thus the copy operation is now virtual and
-  furthermore is localised to the individual subclass. 
+We uses a solution to the non-virtual copy constructor problem which is
+suggested by Ellis and Stroustrup in "The Annotated LRM". 
+The solution is to require the 'T' class to provide a virtual clone method for every
+class which makes a copy using new and the correct copy constructor,
+returning the result as a pointer to the superclass 'T'.
+Each subclass of 'T' overloads this function with its own variant
+which copies its own type. Thus the copy operation is now virtual and
+furthermore is localized to the individual subclass. 
 
-NOCOPY VARIANT:       
-  @noindent
-  This variant of the smart pointer is designed for use on objects that
-  cannot (or must not) be copied. An example would be when managing an 
-  object that contains, say, a file handle. It is essential that this
-  not be copied because then you get the problem of deciding which copy
-  is responsible for closing the file. To avoid the problem, wrap the file
-  handle in a class and then manage a unique instance of it using a 
-  @code{smart_pointer_nocopy}.
-  This ensures that the file handle cannot be copied and is closed when the last alias is destroyed.
+Nocopy variant
+==============
+The smart_pointer_nocopy variant 
+is designed for use on objects that
+cannot (or must not) be copied. An example would be when managing an 
+object that contains, say, a file handle. It is essential that this
+not be copied because then you get the problem of deciding which copy
+is responsible for closing the file. To avoid the problem, wrap the file
+handle in a class and then manage a unique instance of it using a 
+smart_pointer_nocopy.
+This ensures that the file handle cannot be copied and is closed when the last alias is destroyed.
  
-  @noindent
-  The interface to the nocopy variant is the same as @code{smart_pointer}
-  but with all operations that perform copying forbidden.
-  In fact, because all three variants are instances of a common superclass,
-  the forbidden methods do exist but will cause an error and exit if they are called.
+The interface to the nocopy variant is the same as smart_pointer
+but with all operations that perform copying forbidden.
+In fact, because all three variants are instances of a common superclass,
+the forbidden methods do exist but will cause an error and exit if they are called.
  
-  The following modifiers cannot be used because they use copying
-  of the pointed-to object and will thereore cause an error:
-  @example
-    T* operator-> ();
-    T& operator* ();
-    T* pointer ();
-    T& data ();
-  @end example
-EFERENCES:
- @example
- [1] A. Geron and F. Tawbi,
-    Pour mieux developer avec C++ : design pattern, STL, RTTI et smart pointers,
-    InterEditions, 1999. Page 118.
- [2] STLplus, http://stlplus.sourceforge.net/stlplus3/docs/smart_ptr.html
-    for the clone and nocopy variants.
- @end example
-End:
+The following modifiers cannot be used because they use copying
+of the pointed-to object and will therefore cause an error:
+
+        T* operator-> ();
+        T& operator* ();
+        T* pointer ();
+        T& data ();
+  
+Reference
+=========
+    [1] A. Geron and F. Tawbi,
+        Pour mieux developer avec C++ : design pattern, STL, RTTI et smart pointers,
+        InterEditions, 1999. Page 118.
+    [2] STLplus: clone and nocopy variants,
+        http://stlplus.sourceforge.net/stlplus3/docs/smart_ptr.html
+
+Example
+=======
+@snippet smart_pointer.h verbatim_smart_pointer_tst
+
+Implementation
+==============
+@showfromfile
+@snippet smart_pointer.h verbatim_smart_pointer
+@snippet smart_pointer.h verbatim_smart_pointer_clone
+@snippet smart_pointer.h verbatim_smart_pointer_nocopy
 */
+} // namespace rheolef
 
 #include "rheolef/compiler.h"
 
 // -----------------------------------------------------------------------
 // smart_pointer_base<T,Copy>
 // -----------------------------------------------------------------------
-namespace rheolef { 
-//<smart_pointer:
+namespace rheolef {
+
 template <class T, class C>
 class smart_pointer_base {
 public:
@@ -151,8 +156,14 @@ private:
     int _n;
     counter (T* p = 0);
     ~counter ();
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
     int operator++ ();
     int operator-- ();
+#pragma GCC diagnostic pop
+  private:
+    counter (const counter&);
+    counter& operator= (const counter&);
   };
   counter *_count;
 public:
@@ -161,7 +172,6 @@ public:
 #endif // TO_CLEAN
   counter* get_count() const { return _count; }
 };
-//>smart_pointer:
 // -----------------------------------------------------------------------
 // counter: inlined
 // -----------------------------------------------------------------------
@@ -177,6 +187,8 @@ smart_pointer_base<T,C>::counter::~counter ()
 {
     delete_macro(_p);
 }
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
 template <class T, class C>
 inline
 int
@@ -193,6 +205,7 @@ smart_pointer_base<T,C>::counter::operator-- ()
     delete(this);
     return 0;
 }
+#pragma GCC diagnostic pop
 // -----------------------------------------------------------------------
 // smart_pointer_base: inlined
 // -----------------------------------------------------------------------
@@ -327,11 +340,13 @@ struct no_copy {
 // -----------------------------------------------------------------------
 // smart_pointer<T>
 // -----------------------------------------------------------------------
+// [verbatim_smart_pointer]
 template <typename T>
 class smart_pointer : public smart_pointer_base<T, details::constructor_copy<T> > {
     typedef details::constructor_copy<T>     C;
     typedef smart_pointer_base<T,C>          base;
   public:
+    typedef T                                handled_type;
     typedef typename base::internal          internal;
     smart_pointer (T* p = 0) : base (p) {}
     smart_pointer (void* count, internal i) : base(count,i) {}
@@ -340,14 +355,17 @@ class smart_pointer : public smart_pointer_base<T, details::constructor_copy<T>
 	base::operator= (x); return *this; }
     ~smart_pointer() {}
 };
+// [verbatim_smart_pointer]
 // -----------------------------------------------------------------------
 // smart_pointer_clone<T>
 // -----------------------------------------------------------------------
+// [verbatim_smart_pointer_clone]
 template <typename T>
 class smart_pointer_clone : public smart_pointer_base<T, details::clone_copy<T> > {
     typedef details::clone_copy<T>     C;
     typedef smart_pointer_base<T,C>    base;
   public:
+    typedef T                          handled_type;
     typedef typename base::internal    internal;
     smart_pointer_clone (T* p = 0) : base (p) {}
     smart_pointer_clone (void* count, internal i) : base(count,i) {}
@@ -356,14 +374,17 @@ class smart_pointer_clone : public smart_pointer_base<T, details::clone_copy<T>
 	base::operator= (x); return *this; }
     ~smart_pointer_clone() {}
 };
+// [verbatim_smart_pointer_clone]
 // -----------------------------------------------------------------------
 // smart_pointer_nocopy<T>
 // -----------------------------------------------------------------------
+// [verbatim_smart_pointer_nocopy]
 template <typename T>
 class smart_pointer_nocopy : public smart_pointer_base<T, details::no_copy<T> > {
     typedef details::no_copy<T>        C;
     typedef smart_pointer_base<T,C>    base;
   public:
+    typedef T                          handled_type;
     typedef typename base::internal    internal;
     smart_pointer_nocopy (T* p = 0) : base (p) {}
     smart_pointer_nocopy (void* count, internal i) : base(count,i) {}
@@ -372,6 +393,90 @@ class smart_pointer_nocopy : public smart_pointer_base<T, details::no_copy<T> >
 	base::operator= (x); return *this; }
     ~smart_pointer_nocopy() {}
 };
-
+// [verbatim_smart_pointer_nocopy]
 }// namespace rheolef
 #endif // _RHEO_SMART_POINTER_H
+
+#ifdef  _RHEO_SMART_POINTER_TST_CC
+// -----------------------------------------------------------------------
+// smart_pointer_tst.cc : here for doxygen, to avoid INPUT in util/tst
+// -----------------------------------------------------------------------
+using namespace rheolef;
+using namespace std;
+
+// [verbatim_smart_pointer_tst]
+// data representation (could be file "container_data.h")
+typedef int T;
+class container_data {
+    private:  
+        T *values;
+        int n;
+    public: 
+	//!      IMPORTANT: 
+	//! the copy constructor 
+        //!       **MAY** 
+	//! performs a complete copy
+	//!
+        container_data (const container_data& x)
+         : values(new T[x.n]), n(x.n)
+        { for (int i=0; i<n;i++) values[i]=x.values[i];}
+        container_data& operator= (const container_data& x) {
+          n = x.n;
+          values = new T[n];
+          for (int i=0; i<n;i++) values[i]=x.values[i];
+	  return *this;
+        }
+        // a customized constructor
+        explicit container_data(int n1)
+         : values(new T[n1]), n(n1) {}
+
+        ~container_data() { delete [] values; }
+
+        // read and write accessors are separated
+        const T& operator[](int i) const 
+		    { return values[i]; }
+              T& operator[](int i)       
+		    { return values[i]; }
+};
+// an interface to data via the Objet class
+//        that count occurrence (could be "container.h")
+//
+class container : private smart_pointer<container_data> {
+public:
+    // the customized cstor
+    explicit container(int n = 0);
+
+    // read/write accessors
+    const T&  operator[](int i) const;
+          T&  operator[](int i);
+};
+// here is the implementation of the interface
+//  (could be "container.c")
+//
+container::container (int n)
+: smart_pointer<container_data> (new container_data(n))
+{}
+const T&
+container::operator[] (int i) const {
+    // use read access data()
+    return data().operator[] (i);
+}
+T&
+container::operator[] (int i) {
+    // use write access data() that check occurrence count
+    return data().operator [] (i);
+}
+// test program
+int main() {
+    container A(10);
+    A[1] = 1;
+    container B = A;
+    B[1] = 2;
+    if (A[1] == B[1]) {
+	    std::cerr << "fatal: It is not a true copy semantic." << std::endl;
+	exit(1);
+    }
+    std::cerr << "It seems to be a true copy semantic." << std::endl;
+}
+// [verbatim_smart_pointer_tst]
+#endif // _RHEO_SMART_POINTER_TST_CC
