@@ -31,8 +31,7 @@ usage() {
    cerr << " ex: irheostream_tst ../test/in-saylr1 hb\n";
    exit (1);
 }
-int main(int argc, char** argv)
-{
+int main(int argc, char** argv) {
     if (argc < 3) usage();
     irheostream data(argv[1], argv[2]);
     if (!data) 
@@ -43,5 +42,4 @@ int main(int argc, char** argv)
         int c = data.get();
         if (c != EOF) cout.put(c);
     }
-    return 0;
 }
