@@ -26,7 +26,10 @@ export TMPDIR="."
 
 status=0
 for file in in-animal-s2; do
-  run "RHEOPATH=.:${TOP_SRCDIR}/skit/tst ./irheostream_tst $file hb 2>/dev/null | /bin/sh $TOP_SRCDIR/config/zdiff ${TOP_SRCDIR}/skit/tst/$file.hb.gz - >/dev/null"
+  run "RHEOPATH=.:${TOP_SRCDIR}/util/tst ./irheostream_tst $file hb > tmp1.hb 2>/dev/null && gzip -dc < ${TOP_SRCDIR}/util/tst/$file.hb.gz > tmp2.hb && diff tmp1.hb tmp2.hb >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
+
+run "rm -f tmp1.hb tmp2.hb"
+
 exit $status
